﻿using System;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Reflection;

namespace MyControls
{
    public class MyButtonActionList: DesignerActionList
    {
        private readonly MyButton _myButton;
        private readonly DesignerActionUIService _designerActionUiSvc = null;

        public MyButtonActionList(IComponent component) : base(component)
        {
            _myButton = component as MyButton;
            _designerActionUiSvc =
                GetService(typeof(DesignerActionUIService))
                    as DesignerActionUIService;
        }

        public string MyProperty
        {
            get => _myButton.MyProperty;
            set
            {
                GetPropertyByName("MyProperty").SetValue(_myButton, value);

                _designerActionUiSvc.Refresh(Component);
            }
        }

        public override DesignerActionItemCollection GetSortedActionItems()
        {
            DesignerActionItemCollection items = new DesignerActionItemCollection();

            items.Add(new DesignerActionHeaderItem("My Smart tag"));

            items.Add(new DesignerActionPropertyItem("MyProperty", "MyProperty"));

            return items;
        }

        private PropertyDescriptor GetPropertyByName(string propName)
        {
            var prop = TypeDescriptor.GetProperties(_myButton)[propName];
            if (null == prop)
                throw new ArgumentException(
                    "Matching MyProperty property not found!",
                    propName);
            return prop;
        }
    }
}